==> cpl-plugin-kmos_1.3.12%2Bdfsg.orig.tar.xz: kmos-1.3.12/kmos/kmos_priv_sky_tweak.h <==
/* 
 *
 * This file is part of the KMOS Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef KMOS_PRIV_SKY_TWEAK_H
#define KMOS_PRIV_SKY_TWEAK_H

/*-----------------------------------------------------------------------------
 *                              Includes
 *----------------------------------------------------------------------------*/

#include <cpl.h>

/*------------------------------------------------------------------------------
 *                        Prototypes
 *----------------------------------------------------------------------------*/

cpl_imagelist * kmos_priv_sky_tweak(
        cpl_imagelist           *   object,
        cpl_imagelist           *   sky,
        const cpl_propertylist  *   header,
        float                       min_frac,
        int                         tbsub,
        int                         ifu_nr) ;

#endif

==> cpl-plugin-kmos_1.3.18%2Bdfsg.orig.tar.xz: kmos-1.3.18/kmos/kmos_priv_sky_tweak.h <==
/* 
 *
 * This file is part of the KMOS Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef KMOS_PRIV_SKY_TWEAK_H
#define KMOS_PRIV_SKY_TWEAK_H

/*-----------------------------------------------------------------------------
 *                              Includes
 *----------------------------------------------------------------------------*/

#include <cpl.h>

/*------------------------------------------------------------------------------
 *                        Prototypes
 *----------------------------------------------------------------------------*/

cpl_imagelist * kmos_priv_sky_tweak(
        cpl_imagelist           *   object,
        cpl_imagelist           *   sky,
        const cpl_propertylist  *   header,
        float                       min_frac,
        int                         tbsub,
        int                         ifu_nr,
        int                         skip_last,
        int                         stretch,
        int                         plot) ;

#endif
